@@ -50,12 +50,13 @@ class BaseBergen:
             force_sync = False,
             loop = None,
             client_type: ClientType = ClientType.CLIENT,
+            log_stream=False,
             **kwargs) -> None:
         
         if jupyter:
-            setLogging(logging.ERROR)
+            setLogging(logging.ERROR, log_stream=False)
         else:
-            setLogging(log)
+            setLogging(log, log_stream=log_stream)
 
 
         self.running_in_sync = force_sync
@@ -73,8 +74,8 @@ class BaseBergen:
         
         if bind: 
             # We only import this here for typehints
-            from bergen.registries.arnheim import set_current_arnheim
-            set_current_arnheim(self)
+            from bergen.registries.client import set_current_client
+            set_current_client(self)
 
         self.auth = auth
 
@@ -98,15 +99,7 @@ class BaseBergen:
 
         self._provider = None
         self._entertainer = None
-
-
-        if auto_negotiate == True:
-            if self.loop.is_running() and not self.running_in_sync: 
-                pass
-            else:
-               self.negotiate()
-
-
+        self.negotiate_additionals = {}
         super().__init__() 
 
     def getLoopAndContext(self):
@@ -195,7 +188,7 @@ class BaseBergen:
         return provider
     
     async def negotiate_async(self):
-        from bergen.constants import NEGOTIATION_GQL
+        from bergen.queries.initiation import NEGOTIATION_GQL
         from bergen.registries.datapoint import get_datapoint_registry
 
         # Instantiate our Main Ward, this is only for Nodes and Pods
@@ -203,7 +196,8 @@ class BaseBergen:
         await self.main_ward.configure()
 
         # We resort escalating to the different client Type protocols
-        self._transcript = await NEGOTIATION_GQL.run_async(ward=self.main_ward, variables={"clientType": self.client_type})
+        print(self.negotiate_additionals)
+        self._transcript = await NEGOTIATION_GQL.run_async(ward=self.main_ward, variables={"clientType": self.client_type, **self.negotiate_additionals})
         
 
         #Lets create our different Wards 
@@ -317,6 +311,23 @@ class BaseBergen:
     async def __aexit__(self,*args, **kwargs):
         await self.disconnect_async()
 
+
+
+    def negotiate(self):
+        self.loop.run_until_complete(self.negotiate_async())
+
+    def disconnect(self):
+        self.loop.run_until_complete(self.disconnect_async())
+
+
+    def __enter__(self):
+        self.negotiate()
+        return self
+
+    def __exit__(self, *args, **kwargs):
+        self.disconnect()
+        
+
     
     @property
     def provider(self):
