@@ -18,6 +18,7 @@ class Bergen(BaseBergen):
 
     def __init__(self,
     config_path = "bergen.yaml",
+    force_new_token = False,
     arkitekt_host: str = None, 
     arkitekt_port: int = None,
     herre_host: str = None,
@@ -26,7 +27,7 @@ class Bergen(BaseBergen):
     client_secret: str = None,
     username: str = None,
     password: str = None,
-    grant_type: GrantType = GrantType.BACKEND,
+    grant_type: GrantType = None,
     bind=True,
     allow_insecure=False,
     **kwargs) -> None:
@@ -37,7 +38,6 @@ class Bergen(BaseBergen):
 
         if os.path.isfile(config_path):
             with open(config_path,"r") as file:
-                logger.info("Using local configuration ")
                 config = yaml.load(file, Loader=yaml.FullLoader)
 
                 if "arkitekt" in config:
@@ -46,6 +46,9 @@ class Bergen(BaseBergen):
                 if "herre" in config:
                     herre_config.update(config["herre"])
 
+        else:
+            raise Exception("No configuration file found! (please add to the directory or specify config_path")
+
 
         if arkitekt_host : arkitekt_config["port"]= arkitekt_host
         if arkitekt_port : arkitekt_config["host"]= arkitekt_port
@@ -62,11 +65,11 @@ class Bergen(BaseBergen):
                 
         herre_config = HerreConfig(**herre_config)
         arkitekt_config = ArkitektConfig(**arkitekt_config)
-        
 
-        if grant_type == GrantType.BACKEND: auth = ArnheimBackendOauth(herre_config)
-        elif grant_type == GrantType.IMPLICIT: auth = ImplicitApplication(herre_config)
-        elif grant_type == GrantType.PASSWORD: auth = LegacyApplication(herre_config, username=username, password=password)
+
+        if herre_config.authorization_grant_type == GrantType.BACKEND: auth = ArnheimBackendOauth(herre_config, force_new_token=force_new_token)
+        elif herre_config.authorization_grant_type == GrantType.IMPLICIT: auth = ImplicitApplication(herre_config, force_new_token=force_new_token)
+        elif herre_config.authorization_grant_type == GrantType.PASSWORD: auth = LegacyApplication(herre_config, username=username, password=password, force_new_token=force_new_token)
         else: raise NotImplementedError("Please Specifiy a valid Grant Type")
 
         super().__init__(auth, arkitekt_config, auto_negotiate=True, bind=bind, **kwargs)
\ No newline at end of file
