@@ -3,6 +3,6 @@ from .assign_critical import AssignCriticalMessage
 from .assign_progress import AssignProgressMessage
 from .assign_return import AssignReturnMessage
 from .bounced_assign import BouncedAssignMessage
-from .bounced_cancel_assign import BouncedCancelAssignMessage
-from .cancel_assign import CancelAssignMessage
-from .assign_yield import AssignYieldsMessage
\ No newline at end of file
+from .assign_yield import AssignYieldsMessage
+from .assign_done import AssignDoneMessage
+from .bounced_forwarded_assign import BouncedForwardedAssignMessage
\ No newline at end of file
