@@ -6,6 +6,7 @@ from .postman.provide import *
 from .postman.unprovide import *
 from .postman.reserve import *
 from .postman.unreserve import *
+from .postman.unassign import *
 from .exception import ExceptionMessage
 import json
 
@@ -13,40 +14,43 @@ import json
 registry = {
     PROVIDE_DONE:  ProvideDoneMessage,
     BOUNCED_PROVIDE: BouncedProvideMessage,
-    BOUNCED_CANCEL_PROVIDE: BouncedCancelProvideMessage,
     PROVIDE_CRITICAL: ProvideCriticalMessage,
     PROVIDE_PROGRESS: ProvideProgressMessage,
     PROVIDE: ProvideMessage,
 
     UNPROVIDE_DONE:  UnprovideDoneMessage,
     BOUNCED_UNPROVIDE: BouncedUnprovideMessage,
-    BOUNCED_CANCEL_UNPROVIDE: BouncedCancelUnprovideMessage,
     UNPROVIDE_CRITICAL: UnprovideCriticalMessage,
     UNPROVIDE_PROGRESS: UnprovideProgressMessage,
     UNPROVIDE: UnprovideMessage,
 
     RESERVE: ReserveMessage,
     BOUNCED_RESERVE: BouncedReserveMessage,
-    BOUNCED_CANCEL_RESERVE: BouncedCancelReserveMessage,
+    BOUNCED_FORWARDED_RESERVE: BouncedForwardedReserveMessage,
     RESERVE_CRITICAL: ReserveCriticalMessage,
     RESERVE_PROGRESS: ReserveProgressMessage,
     RESERVE_DONE: ReserveDoneMessage,
 
     UNRESERVE: UnreserveMessage,
     BOUNCED_UNRESERVE: BouncedUnreserveMessage,
-    BOUNCED_CANCEL_UNRESERVE: BouncedCancelUnreserveMessage,
     UNRESERVE_CRITICAL: UnreserveCriticalMessage,
     UNRESERVE_PROGRESS: UnreserveProgressMessage,
     UNRESERVE_DONE: UnreserveDoneMessage,
 
     ASSIGN: AssignMessage,
-    CANCEL_ASSIGN: CancelAssignMessage,
+    BOUNCED_ASSIGN: BouncedAssignMessage,
+    BOUNCED_FORWARDED_ASSIGN: BouncedForwardedAssignMessage,
     ASSIGN_CRITICAL: AssignCriticalMessage,
     ASSIGN_PROGRES: AssignProgressMessage,
     ASSIGN_RETURN: AssignReturnMessage,
+    ASSIGN_DONE: AssignDoneMessage,
     ASSIGN_YIELD: AssignYieldsMessage,
-    BOUNCED_ASSIGN: BouncedAssignMessage,
-    BOUNCED_CANCEL_ASSIGN: BouncedCancelAssignMessage,
+
+    UNASSIGN: UnassignMessage,
+    BOUNCED_UNASSIGN: BouncedUnassignMessage,
+    UNASSIGN_CRITICAL: UnassignCriticalMessage,
+    UNASSIGN_PROGRES: UnassignProgressMessage,
+    UNASSIGN_DONE: UnassignDoneMessage,
 
     ACTIVATE_POD: ActivatePodMessage,
     DEACTIVATE_POD: DeActivatePodMessage,
