@@ -9,7 +9,7 @@ class ModelReturnPort(BaseReturnPort):
 
   def __init__(self, modelClass: Type[ArnheimModel],**kwargs) -> None:
       self.modelClass = modelClass
-      super().__init__("model", **kwargs)
+      super().__init__(**kwargs)
 
   def serialize(self):
       return {**super().serialize(),"identifier" : self.modelClass.getMeta().identifier}
\ No newline at end of file
